@@ -32,9 +32,12 @@ class Pandora:
 		req = xmlrpclib.dumps( (), "misc.sync" ).replace( "\n", "" )
 		enc = crypt.encryptString( req )
 
-		u = urlopen( reqUrl, enc )
-		resp = u.read()
-		u.close()
+		try:
+			u = urlopen( reqUrl, enc )
+			resp = u.read()
+			u.close()
+		except:
+			return False
 
 	def authListener( self, user, pwd ):
 		reqUrl = BASE_URL_RID %( self.rid, "authenticateListener" )
@@ -44,9 +47,12 @@ class Pandora:
 		req = req.replace( "\n", "" )
 		enc = crypt.encryptString( req )
 
-		u = urlopen( reqUrl, enc )
-		resp = u.read()
-		u.close()
+		try:
+			u = urlopen( reqUrl, enc )
+			resp = u.read()
+			u.close()
+		except:
+			return False
 
 		try:
 			parsed = xmlrpclib.loads( resp )[0][0]
@@ -57,7 +63,6 @@ class Pandora:
 
 		self.authToken = parsed["authToken"]
 		self.lid = parsed["listenerId"]
-		
 		return True
 
 	def getStations( self ):
@@ -72,7 +77,12 @@ class Pandora:
 		resp = u.read()
 		u.close()
 		
-		parsed = xmlrpclib.loads( resp )[0][0]
+		try:
+			parsed = xmlrpclib.loads( resp )[0][0]
+		except xmlrpclib.Fault, fault:
+			parsed = xmlrpclib.loads( resp )
+			print "Error:", fault.faultString
+			print "Code:", fault.faultCode
 
 		return parsed
 
@@ -97,7 +107,12 @@ class Pandora:
 		resp = u.read()
 		u.close()
 
-		parsed = xmlrpclib.loads( resp )[0][0]
+		try:
+			parsed = xmlrpclib.loads( resp )[0][0]
+		except xmlrpclib.Fault, fault:
+			parsed = xmlrpclib.loads( resp )
+			print "Error:", fault.faultString
+			print "Code:", fault.faultCode
 
 		return parsed
 
@@ -117,7 +132,12 @@ class Pandora:
 		resp = u.read()
 		u.close
 
-		parsed = xmlrpclib.loads( resp )[0][0]
+		try:
+			parsed = xmlrpclib.loads( resp )[0][0]
+		except xmlrpclib.Fault, fault:
+			parsed = xmlrpclib.loads( resp )
+			print "Error:", fault.faultString
+			print "Code:", fault.faultCode
 
 		return parsed
 
@@ -137,7 +157,12 @@ class Pandora:
 		resp = u.read()
 		u.close
 
-		parsed = xmlrpclib.loads( resp )[0][0]
+		try:
+			parsed = xmlrpclib.loads( resp )[0][0]
+		except xmlrpclib.Fault, fault:
+			parsed = xmlrpclib.loads( resp )
+			print "Error:", fault.faultString
+			print "Code:", fault.faultCode
 
 		return parsed  	
 
@@ -157,7 +182,12 @@ class Pandora:
 		resp = u.read()
 		u.close
 
-		parsed = xmlrpclib.loads( resp )[0][0]
+		try:
+			parsed = xmlrpclib.loads( resp )[0][0]
+		except xmlrpclib.Fault, fault:
+			parsed = xmlrpclib.loads( resp )
+			print "Error:", fault.faultString
+			print "Code:", fault.faultCode
 
 		return parsed  
 				
@@ -177,7 +207,12 @@ class Pandora:
 		resp = u.read()
 		u.close
 
-		parsed = xmlrpclib.loads( resp )[0][0]
+		try:
+			parsed = xmlrpclib.loads( resp )[0][0]
+		except xmlrpclib.Fault, fault:
+			parsed = xmlrpclib.loads( resp )
+			print "Error:", fault.faultString
+			print "Code:", fault.faultCode
 
 		return parsed  
 
@@ -198,7 +233,12 @@ class Pandora:
 		resp = u.read()
 		u.close()
 
-		parsed = xmlrpclib.loads( resp )[0][0]
+		try:
+			parsed = xmlrpclib.loads( resp )[0][0]
+		except xmlrpclib.Fault, fault:
+			parsed = xmlrpclib.loads( resp )
+			print "Error:", fault.faultString
+			print "Code:", fault.faultCode
 
 		#last 48 chars of URL encrypted, padded w/ 8 * '\x08'
 		for i in range( len( parsed ) ):
