@@ -4,6 +4,7 @@ import pygst
 pygst.require('0.10')
 import gst
 
+from libpiano.pulse_calls import *
 from libpiano.pandora import Pandora
 from PyQt4 import QtCore
 
@@ -48,16 +49,14 @@ class RadioPlayer(QtCore.QThread):
 		self.pandora.sync()
 		self.player = gst.element_factory_make("playbin2", "player")
 		fakesink = gst.element_factory_make("fakesink", "fakesink")
+		pulsesink = gst.element_factory_make("pulsesink", "pulsesink")
+		proplist = pa_proplist_new()
+		pa_proplist_sets (proplist, "event.id", "ringtone-preview")
+		g_object_set(c_void_p(hash(pulsesink)), "proplist", proplist, None)
+		pulsesink.set_property("buffer-time", 512000)
+		self.player.set_property("audio-sink", pulsesink)
 		self.player.set_property("video-sink", fakesink)
 		self.player.set_property("buffer-size", 512000)
-		#self.player.set_property("buffer-duration", 512000)
-		#self.bin = gst.parse_launch('playbin2 name=source')
-						#'uridecodebin name=uridecode ! ' +
-						#'volume name=volume ! ' +
-						#'speed name=speed ! ' +
-						#'audioresample ! ' +
-						#'pulsesink name=pulsesink')
-		#self.player = self.bin.get_by_name('source')
 		bus = self.player.get_bus()
 		bus.add_signal_watch()
 		bus.connect("message::eos", self.onPlayBackEnded)
